# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]
## [0.1] - 2026-04-03
### Added
- `generate_noise` function
- `play_noise` function
- White noise
- Pink noise
- Brown noise

[Unreleased]: https://github.com/sepandhaghighi/zenix/compare/v0.1...dev
[0.1]: https://github.com/sepandhaghighi/zenix/compare/815762c...v0.1



